pub fn get_state_delta(state: &RepoState, summary: &RepoSummary) -> RepoStateExpand description
Compute the delta a peer needs to update from summary to state.
pub fn get_state_delta(state: &RepoState, summary: &RepoSummary) -> RepoStateCompute the delta a peer needs to update from summary to state.